@@ -124,8 +124,10 @@ sji.getValueLabel <- function(x) {
 #'          the \code{"value.labels"} attribute. The length of this character vector must equal
 #'          the value range of \code{"x"}, i.e. if \code{"x"} has values from 1 to 3,
 #'          \code{"labels"} should have a length of 3. 
-#'          If \code{"x"} is a data frame, \code{labels} must be a \code{\link{list}} of
-#'          character vectors.
+#'          If \code{"x"} is a data frame, \code{labels} may also be a \code{\link{list}} of
+#'          character vectors. If \code{labels} is a list, it must have the same length as
+#'          number of columns of \code{x}. If \code{labels} is a vector and \code{x} is a data frame,
+#'          the \code{labels} will be applied to each column of \code{x}.
 #' @return \code{"x"} with attached value labels.
 #' 
 #' @examples
@@ -142,7 +144,15 @@ sji.setValueLabels <- function(x, labels) {
   }
   else if (is.data.frame(x) || is.matrix(x)) {
     for (i in 1:ncol(x)) {
-      x[,i] <- sji.setValueLabels.vector(x[,i], labels[[i]])
+      if (is.vector(labels)) {
+        x[,i] <- sji.setValueLabels.vector(x[,i], labels)
+      }
+      else if (is.list(labels)) {
+        x[,i] <- sji.setValueLabels.vector(x[,i], labels[[i]])
+      }
+      else {
+        warning("'labels' must be a list of same length as 'ncol(x)' or a vector.", call. = F)
+      }
     }
     return (x)
   }
