@@ -2,27 +2,46 @@
 if(getRversion() >= "2.15.1") utils::globalVariables(c("vars", "Beta", "xv", "lower", "upper", "stdbeta", "p", "x", "ydiff", "y", "grp", ".stdresid", ".resid", ".fitted", "V1", "V2"))
 
 
-#' @title Plot beta coefficients of lm
+#' @title Plot linear models
 #' @name sjp.lm
 #' 
 #' @seealso \itemize{
 #'              \item \href{http://www.strengejacke.de/sjPlot/sjp.lm}{sjPlot manual: sjp.lm}
-#'              \item \code{\link{sjp.lm.ma}}
-#'              \item \code{\link{sjp.reglin}}
 #'              \item \code{\link{sjp.int}}
 #'              \item \code{\link{sjp.scatter}}
 #'              \item  \code{\link{sjs.stdb}}
 #'             }
 #' 
-#' @description Plot beta coefficients (estimates) of linear regressions with confidence intervalls as dot plot
-#'                (forest plot). Additionally, the standardized beta values are plotted
-#'                as red dots.
+#' @description Depending on the \code{type}, this function plots beta coefficients (estimates) 
+#'                of linear regressions with confidence intervalls as dot plot (forest plot),
+#'                model assumptions for linear models or slopes and scatter plots for each single
+#'                coefficient. See \code{type} for details.
+#' 
+#' @details \itemize{
+#'            \item If \code{type = "lm"} and fitted model only has one predictor, no forest plot is shown. Instead, a regression line with confidence interval (in blue) is plotted by default, and a loess-smoothed line without confidence interval (in red) can be added if parameter \code{showLoess} is \code{TRUE}.
+#'            \item If \code{type = "pred"}, regression lines with confidence intervals for each single predictor of the fitted model are plotted, i.e. all predictors of the fitted model are extracted and each of them are fitted against the response variable.
+#'            \item If \code{type = "ma"} (i.e. checking model assumptions), please note that only three parameters are relevant: \code{fit}, \code{completeDiagnostic} and \code{showOriginalModelOnly}. All other parameters are ignored.
+#'            \item If \code{type = "vif"}, the Variance Inflation Factors (check for multicollinearity) are plotted. As a rule of thumb, values below 5 are considered as good and indicate no multicollinearity, values between 5 and 10 may be tolerable. Values greater than 10 are not acceptable and indicate multicollinearity between model's predictors.
+#'            }
 #'                
-#' @param fit The model of the linear regression (lm-Object).
+#' @param fit The model of the linear regression (\code{\link{lm}}-Object).
+#' @param type type of plot. Use one of following:
+#'          \itemize{
+#'            \item \code{"lm"} (default) for forest-plot like plot of estimates. If the fitted model only contains one predictor, intercept and slope are plotted.
+#'            \item \code{"std"} for forest-plot like plot of standardized beta values. If the fitted model only contains one predictor, intercept and slope are plotted.
+#'            \item \code{"pred"} to plot regression lines for each single predictor of the fitted model.
+#'            \item \code{"ma"} to check model assumptions. Note that only three parameters are relevant for this option \code{fit}, \code{completeDiagnostic} and \code{showOriginalModelOnly}. All other parameters are ignored.
+#'            \item \code{"vif"} to plot Variance Inflation Factors. See details.
+#'          }
 #' @param title Diagram's title as string.
 #'          Example: \code{title=c("my title")}
-#' @param sort Determines whether the predictors are sorted by beta-values (default, or use \code{"beta"} as
-#'          parameter) or by standardized beta values (use \code{"std"}).
+#' @param sort.est Logical, determines whether estimates should be sorted by their values.
+#' @param axisLabels.x Labels of the predictor (independent variable) that is used for labelling the
+#'          axis. Passed as string. Not used if fitted model has more than one predictor and \code{type = "lm"}.
+#'          Example: \code{axisLabel.x=c("My Predictor Var")}.
+#'          Note: If you use the \code{\link{sji.SPSS}} function and the \code{\link{sji.getVariableLabels}} function, you receive a
+#'          character vector with variable label strings. You can use it like so:
+#'          \code{axisLabel.x=sji.getVariableLabels(efc)['quol_5']}
 #' @param axisLabels.y Labels of the predictor variables (independent vars) that are used for labelling the
 #'          axis. Passed as vector of strings.
 #'          Example: \code{axisLabels.y=c("Label1", "Label2", "Label3")}.
@@ -44,10 +63,6 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("vars", "Beta", "xv", "lo
 #'          }
 #'          Else specify your own color values as vector (e.g. \code{geom.colors=c("#f00000", "#00ff00")}).
 #' @param geom.size size resp. width of the geoms (bar width or point size, depending on \code{type} parameter).
-#' @param stdBetaLineType The standardized beta-value dots are connected by a thin line
-#'          for a better overview. With this parameter you can specify the line type.
-#' @param stdBetaLineAlpha The alpha-value for the line that connects the
-#'          standardized beta-value dots.
 #' @param interceptLineType The linetype of the intercept line (zero point). Default is \code{2} (dashed line).
 #' @param interceptLineColor The color of the intercept line. Default value is \code{"grey70"}.
 #' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
@@ -67,52 +82,204 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("vars", "Beta", "xv", "lo
 #' @param showModelSummary If \code{TRUE} (default), a summary of the regression model with 
 #'          Intercept, R-square, F-Test and AIC-value is printed to the lower right corner
 #'          of the diagram.
-#' @param showStandardBeta Whether or not the dots for the standardized beta values 
-#'          should be plotted to the diagram.
-#' @param showStandardBetaLine Whether or not the connecting line for the standardized beta values 
-#'          should be plotted to the diagram. Default is \code{FALSE}.
+#' @param lineColor The color of the regression line. Default is \code{"blue"}.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param showCI If \code{TRUE} (default), a confidence region for the regression line
+#'          will be plotted. Use \code{ciLevel} to specifiy the confidence level.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param ciLevel The confidence level of the confidence region. Only applies when
+#'          \code{showCI} is \code{TRUE}. Default is 0.95.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param pointAlpha The alpha values of the scatter plot's point-geoms.
+#'          Default is 0.2.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param pointColor The color of the scatter plot's point-geoms. Only applies when \code{showScatterPlot}
+#'          is \code{TRUE}. Default is \code{"black"}.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param showScatterPlot If \code{TRUE} (default), a scatter plot of response and predictor values
+#'          for each predictor of the fitted model \code{fit} is plotted.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param showLoess If \code{TRUE}, an additional loess-smoothed line is plotted.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param loessLineColor The color of the loess-smoothed line. Default is \code{"red"}. Only applies, if
+#'          \code{showLoess} is \code{TRUE}.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param showLoessCI If \code{TRUE}, a confidence region for the loess-smoothed line
+#'          will be plotted. Default is \code{FALSE}. Use \code{loessCiLevel} to specifiy the confidence level.
+#'          Only applies, if \code{showLoess} is \code{TRUE}.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param loessCiLevel The confidence level of the loess-line's confidence region.
+#'          Only applies, if \code{showLoessCI} is \code{TRUE}. Default is 0.95.
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param useResiduals If \code{TRUE}, the residuals (instead of response) are plotted 
+#'          against the predictor. May be used for model diagnostics
+#'          (see \url{https://www.otexts.org/fpp/5/4}).
+#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
+#'          or if \code{type = "pred"}.
+#' @param showOriginalModelOnly if \code{TRUE} (default), only the model assumptions of the fitted model
+#'          \code{fit} are plotted. if \code{FALSE}, the model assumptions of an updated model where outliers
+#'          are automatically excluded are also plotted.
+#'          Only applies if \code{type = "ma"}.
+#' @param completeDiagnostic if \code{TRUE}, additional tests are performed. Default is \code{FALSE}
+#'          Only applies if \code{type = "ma"}.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
 #'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
-#' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
-#'           was used for setting up the ggplot-object (\code{df}).
+#' @return Depending on the \code{type}, in most cases (insisibily) 
+#'           returns the ggplot-object with the complete plot (\code{plot}) 
+#'           as well as the data frame that was used for setting up the 
+#'           ggplot-object (\code{df}).
 #' 
 #' @examples
+#' # --------------------------------------------------
+#' # plotting estimates of linear models as forest plot
+#' # --------------------------------------------------
 #' # fit linear model
 #' fit <- lm(airquality$Ozone ~ airquality$Wind + airquality$Temp + airquality$Solar.R)
 #' 
-#' # plot estimates with CI and standardized beta-values
-#' sjp.lm(fit, gridBreaksAt=2)
+#' # plot estimates with CI
+#' sjp.lm(fit, gridBreaksAt = 2)
 #' 
 #' # plot estimates with CI without standardized beta-values
 #' # and with narrower tick marks (because "gridBreaksAt" was not specified)
-#' sjp.lm(fit, showStandardBeta=FALSE)
+#' sjp.lm(fit)
 #' 
+#' # ---------------------------------------------------
+#' # plotting regression line of linear model (done 
+#' # automatically if fitted model has only 1 predictor)
+#' # ---------------------------------------------------
+#' data(efc)
+#' # fit model
+#' fit <- lm(neg_c_7 ~ quol_5, data=efc)
+#' # plot regression line
+#' sjp.lm(fit)
+#' # plot regression line with label strings
+#' sjp.lm(fit,
+#'        axisLabels.x = "Quality of life",
+#'        axisLabels.y = "Burden of care",
+#'        showLoess = TRUE)
+#'         
+#' # --------------------------------------------------
+#' # plotting regression lines of each single predictor
+#' # of a fitted model
+#' # --------------------------------------------------
+#' # fit model
+#' fit <- lm(tot_sc_e ~ c12hour + e17age + e42dep, data=efc)
+#' 
+#' # reression line and scatter plot
+#' sjp.lm(fit, type = "pred")
+#'            
+#' # reression line w/o scatter plot
+#' sjp.lm(fit, 
+#'        type = "pred",
+#'        showScatterPlot = FALSE)
+#'         
+#' # --------------------------
+#' # plotting model assumptions
+#' # --------------------------
+#' sjp.lm(fit, type = "ma")
+#'         
 #' @import ggplot2
+#' @importFrom car outlierTest crPlots durbinWatsonTest leveragePlots ncvTest spreadLevelPlot vif
 #' @export
 sjp.lm <- function(fit,
-                    sort="beta",
-                    title=NULL,
-                    axisLabels.y=NULL, 
-                    showAxisLabels.y=TRUE,
-                    axisTitle.x="Estimates",
-                    axisLimits=NULL,
-                    geom.colors="Set1",
-                    geom.size=3,
-                    stdBetaLineType=2,
-                    stdBetaLineAlpha=0.3,
-                    interceptLineType=2,
-                    interceptLineColor="grey70",
-                    breakTitleAt=50, 
-                    breakLabelsAt=25, 
-                    gridBreaksAt=NULL,
-                    coord.flip=TRUE,
-                    showValueLabels=TRUE, 
-                    labelDigits=2,
-                    showPValueLabels=TRUE,
-                    showModelSummary=TRUE,
-                    showStandardBeta=FALSE,
-                    showStandardBetaLine=FALSE,
-                    printPlot=TRUE) {
+                   type="lm",
+                   sort.est=TRUE,
+                   title=NULL,
+                   axisLabels.x=NULL,
+                   axisLabels.y=NULL, 
+                   showAxisLabels.y=TRUE,
+                   axisTitle.x="Estimates",
+                   axisLimits=NULL,
+                   geom.colors="Set1",
+                   geom.size=3,
+                   interceptLineType=2,
+                   interceptLineColor="grey70",
+                   breakTitleAt=50, 
+                   breakLabelsAt=25, 
+                   gridBreaksAt=NULL,
+                   coord.flip=TRUE,
+                   showValueLabels=TRUE, 
+                   labelDigits=2,
+                   showPValueLabels=TRUE,
+                   showModelSummary=TRUE,
+                   lineColor="blue",
+                   showCI=TRUE,
+                   ciLevel=0.95,
+                   pointAlpha=0.2,
+                   pointColor="black",
+                   showScatterPlot=TRUE,
+                   showLoess=FALSE,
+                   loessLineColor="red",
+                   showLoessCI=FALSE,
+                   loessCiLevel=0.95,
+                   useResiduals=FALSE,
+                   showOriginalModelOnly=TRUE, 
+                   completeDiagnostic=FALSE,
+                   printPlot=TRUE) {
+  # -----------------------------------------------------------
+  # remember length of predictor variables
+  # -----------------------------------------------------------
+  predvars.length <- length(fit$coefficients)
+  # -----------------------------------------------------------
+  # this function requires a fitted model with only one predictor,
+  # so check whether only one predictor was used
+  # -----------------------------------------------------------
+  if (type == "lm" && predvars.length <= 2) {
+    return (invisible(sjp.lm1(fit,
+                              title,
+                              breakTitleAt, 
+                              axisLabels.x,
+                              axisLabels.y,
+                              breakLabelsAt,
+                              lineColor,
+                              showCI,
+                              ciLevel,
+                              pointAlpha,
+                              pointColor,
+                              showScatterPlot,
+                              showLoess,
+                              loessLineColor,
+                              showLoessCI,
+                              loessCiLevel,
+                              showModelSummary,
+                              useResiduals,
+                              printPlot)))
+  }
+  if (type == "pred") {
+    return (invisible(sjp.reglin(fit,
+                                 title,
+                                 breakTitleAt, 
+                                 lineColor,
+                                 showCI,
+                                 ciLevel,
+                                 pointAlpha,
+                                 pointColor,
+                                 showScatterPlot,
+                                 showLoess,
+                                 loessLineColor,
+                                 showLoessCI,
+                                 loessCiLevel,
+                                 useResiduals,
+                                 printPlot)))
+  }
+  if (type == "ma") {
+    return (invisible(sjp.lm.ma(fit,
+                                showOriginalModelOnly,
+                                completeDiagnostic)))
+  }
+  if (type == "vif") {
+    return (invisible(sjp.vif(fit)))
+  }
   # --------------------------------------------------------
   # unlist labels
   # --------------------------------------------------------
@@ -173,10 +340,10 @@ sjp.lm <- function(fit,
   # retrieve betas, leave out intercept ([-1])
   bv <- coef(fit)[-1]
   # retrieve standardized betas
-  stdbv <- sjs.stdb(fit)
+  stdbv <- sjs.stdb(fit, include.ci = TRUE)
   # init data column for p-values
   ps <- sprintf("%.*f", labelDigits, bv)
-  pstdbv <- sprintf("%.*f", labelDigits, stdbv)
+  pstdbv <- sprintf("%.*f", labelDigits, stdbv$beta)
   # if no values should be shown, clear
   # vector now
   if (!showValueLabels) {
@@ -192,12 +359,15 @@ sjp.lm <- function(fit,
       }
       else if (pv[i]>=0.01 && pv[i]<0.05) {
         ps[i] <- paste(ps[i], "*")
+        pstdbv[i] <- paste(pstdbv[i], "*")
       }
       else if (pv[i]>=0.001 && pv[i]<0.01) {
         ps[i] <- paste(ps[i], "**")
+        pstdbv[i] <- paste(pstdbv[i], "**")
       }
       else {
         ps[i] <- paste(ps[i], "***")
+        pstdbv[i] <- paste(pstdbv[i], "***")
       }
     }  
   }
@@ -208,29 +378,35 @@ sjp.lm <- function(fit,
   # if we have only one independent variable, cbind does not
   # work, since it duplicates the coefficients. so we simply
   # concatenate here
-  if (1==length(coefficients(fit)[-1])) {
-    tmp <- data.frame(
-      # Append beta coefficients, [-1] means that the first
-      # row (Intercept) will be removed / ignored
-      coefficients(fit)[-1],
-      # append CI
-      confint(fit, level=0.95)[-1,1],
-      confint(fit, level=0.95)[-1,2])
+  if (type == "std") {
+    tmp <- stdbv
+    ps <- pstdbv
   }
   else {
-    tmp <- data.frame(cbind(
-      # Append beta coefficients, [-1] means that the first
-      # row (Intercept) will be removed / ignored
-      coefficients(fit)[-1],
-      # append CI
-      confint(fit, level=0.95)[-1,]))
+    if (1==length(coefficients(fit)[-1])) {
+      tmp <- data.frame(
+        # Append beta coefficients, [-1] means that the first
+        # row (Intercept) will be removed / ignored
+        coefficients(fit)[-1],
+        # append CI
+        confint(fit, level=0.95)[-1,1],
+        confint(fit, level=0.95)[-1,2])
+    }
+    else {
+      tmp <- data.frame(cbind(
+        # Append beta coefficients, [-1] means that the first
+        # row (Intercept) will be removed / ignored
+        coefficients(fit)[-1],
+        # append CI
+        confint(fit, level=0.95)[-1,]))
+    }
   }
   # append p-values and standardized beta coefficients
   # further more, we take the stand. beta as string, because in
   # case no values are drawn, we simply use an empty string.
   # finally, we need the p-values of the coefficients, because the value
   # labels may have different colours according to their significance level
-  betas <- cbind(tmp, c(ps), sjs.stdb(fit), c(pstdbv), pv)
+  betas <- cbind(tmp, c(ps), pv)
   # --------------------------------------------------------
   # check if user defined labels have been supplied
   # if not, use variable names from data frame
@@ -248,25 +424,21 @@ sjp.lm <- function(fit,
   # beta values (sort = anything else)
   # --------------------------------------------------------
   # sort labels descending in order of (std.) beta values
-  # --------------------------------------------------------
-  if (sort=="beta") {
-    axisLabels.y <- axisLabels.y[order(bv)]
-  }
-  else {
-    axisLabels.y <- axisLabels.y[order(stdbv)]
-  }
-  # --------------------------------------------------------
   # sort rows of data frame descending in order of (std.) beta values
   # --------------------------------------------------------
-  if (sort=="beta") {
-    betas <- betas[order(bv),]
-  }
-  else {
-    betas <- betas[order(stdbv),]
+  if (sort.est) {
+    if (type == "lm") {
+      axisLabels.y <- axisLabels.y[order(bv)]
+      betas <- betas[order(bv),]
+    }
+    else if (type == "std") {
+      axisLabels.y <- axisLabels.y[order(stdbv$beta)]
+      betas <- betas[order(stdbv$beta),]
+    }
   }
   betas <- cbind(c(seq(1:nrow(betas))), betas)
   # give columns names
-  names(betas)<-c("xv", "Beta", "lower", "upper", "p", "stdbeta", "pstdbv", "pv")
+  names(betas)<-c("xv", "Beta", "lower", "upper", "p", "pv")
   betas$p <- as.character(betas$p)
   # --------------------------------------------------------
   # Calculate axis limits. The range is from lowest lower-CI
@@ -294,26 +466,11 @@ sjp.lm <- function(fit,
   # --------------------------------------------------------
   # Start plot here!
   # --------------------------------------------------------
-  # show points for standard beta values
-  if (showStandardBeta) {
-    betaplot <- ggplot(betas, aes(y=stdbeta, x=xv, colour=Beta>=0)) +
-      # Print std.beta-values. With vertical adjustment, so they don't overlap with the errorbars
-      geom_text(aes(label=pstdbv, y=stdbeta), vjust=1.8, show_guide=FALSE)
-      # to better distinguish betas and stand. betas, the stand. beta points can be connected with a line
-    if (showStandardBetaLine) {
-      # print line for standardized beta values
-      betaplot <- betaplot +
-        geom_line()
-    }
-  }
-  else {
-    betaplot <- ggplot(betas, aes(y=Beta, x=xv, colour=Beta>=0)) +
-      # and error bar
-      geom_errorbar(aes(ymin=lower, ymax=upper), width=0) +
-      # Print p-values. With vertical adjustment, so they don't overlap with the errorbars
-      geom_text(aes(label=p, y=Beta), vjust=-0.8, show_guide=FALSE)
-  }
-  betaplot <- betaplot +
+  betaplot <- ggplot(betas, aes(y=Beta, x=xv, colour=Beta>=0)) +
+    # and error bar
+    geom_errorbar(aes(ymin=lower, ymax=upper), width=0) +
+    # Print p-values. With vertical adjustment, so they don't overlap with the errorbars
+    geom_text(aes(label=p, y=Beta), vjust=-0.8, show_guide=FALSE) +
     # print point
     geom_point(size=geom.size) +
     # Intercept-line
@@ -352,75 +509,6 @@ sjp.lm <- function(fit,
 }
 
 
-#' @title Plot regression lines for each predictor
-#' @name sjp.reglin
-#' 
-#' @description Plot regression lines with confidence intervals for each single predictor of
-#'                a fitted model. This method extracts all predictors of a fitted model and fits 
-#'                each of them against the response variable. \cr \cr
-#'                This function plots two lines: The resulting linear regression line
-#'                including confidence interval (in blue) and a loess-smoothed line without
-#'                confidence interval (in red). The better the linear relationship
-#'                of predictor and response is, the more both lines should overlap
-#'                (i.e. the red loess-smoothed line is almost linear). \cr \cr
-#'                Furthermore, a scatter plot of response and predictor values
-#'                is plotted.
-#'                
-#' @seealso \itemize{
-#'              \item \href{http://www.strengejacke.de/sjPlot/sjp.lm}{sjPlot manual: sjp.lm}
-#'              \item \code{\link{sjp.lm}}
-#'              \item \code{\link{sjp.lm.ma}}
-#'              \item \code{\link{sjp.int}}
-#'              \item \code{\link{sjp.scatter}}
-#'             }
-#'          
-#' @param fit The model of the linear regression (lm-Object).
-#' @param title Diagram's title as string. By default \code{NULL}, i.e. no
-#'          title is shown. Example: \code{title=c("my title")}
-#' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
-#'          one line and when a line break is inserted into the title
-#' @param lineColor The color of the regression line. Default is \code{"blue"}.
-#' @param showCI If \code{TRUE} (default), a confidence region for the regression line
-#'          will be plotted. Use \code{ciLevel} to specifiy the confidence level.
-#' @param ciLevel The confidence level of the confidence region. Only applies when
-#'          \code{showCI} is \code{TRUE}. Default is 0.95.
-#' @param pointAlpha The alpha values of the scatter plot's point-geoms.
-#'          Default is 0.2.
-#' @param pointColor The color of the scatter plot's point-geoms. Only applies when \code{showScatterPlot}
-#'          is \code{TRUE}. Default is \code{"black"}.
-#' @param showScatterPlot If \code{TRUE} (default), a scatter plot of response and predictor values
-#'          for each predictor of the fitted model \code{fit} is plotted.
-#' @param showLoess If \code{TRUE} (default), an additional loess-smoothed line is plotted.
-#' @param loessLineColor The color of the loess-smoothed line. Default is \code{"red"}. Only applies, if
-#'          \code{showLoess} is \code{TRUE}.
-#' @param showLoessCI If \code{TRUE}, a confidence region for the loess-smoothed line
-#'          will be plotted. Default is \code{FALSE}. Use \code{loessCiLevel} to specifiy the confidence level.
-#'          Only applies, if \code{showLoess} is \code{TRUE}.
-#' @param loessCiLevel The confidence level of the loess-line's confidence region.
-#'          Only applies, if \code{showLoessCI} is \code{TRUE}. Default is 0.95.
-#' @param useResiduals If \code{TRUE}, the residuals (instead of response) are plotted 
-#'          against each predictor. May be used for model diagnostics
-#'          (see \url{https://www.otexts.org/fpp/5/4}).
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
-#' @return (Insisibily) returns the ggplot-objects with the complete plot-list (\code{plot.list}) 
-#'           as well as the data frame that were used for setting up the ggplot-objects (\code{df.list}).
-#' 
-#' @examples
-#' data(efc)
-#' fit <- lm(tot_sc_e ~ c12hour + e17age + e42dep, data=efc)
-#' 
-#' # reression line and scatter plot
-#' sjp.reglin(fit)
-#'            
-#' # reression line w/o scatter plot
-#' sjp.reglin(fit, showScatterPlot=FALSE)
-#' 
-#' # reression line w/o CI
-#' sjp.reglin(fit, showCI=FALSE)
-#' 
-#' @import ggplot2
-#' @export
 sjp.reglin <- function(fit,
                        title=NULL,
                        breakTitleAt=50,
@@ -524,39 +612,6 @@ sjp.reglin <- function(fit,
 }
 
 
-#' @title Plot model assumptions of lm's
-#' @name sjp.lm.ma
-#' 
-#' @description Plots model assumptions of linear models to verify if linear regression is applicable
-#' 
-#' @references \url{https://www.otexts.org/fpp/5/4}
-#' 
-#' @seealso \itemize{
-#'              \item \href{http://www.strengejacke.de/sjPlot/sjp.lm}{sjPlot manual: sjp.lm}
-#'              \item \code{\link{sjp.lm}}
-#'              \item \code{\link{sjp.reglin}}
-#'              \item \code{\link{sjp.int}}
-#'             }
-#'          
-#' @param linreg a fitted lm-model
-#' @param showOriginalModelOnly if \code{TRUE} (default), only the model assumptions of the fitted model
-#'   \code{linreg} are plotted. if \code{FALSE}, the model assumptions of an updated model where outliers
-#'   are automatically excluded are also plotted.
-#' @param completeDiagnostic if \code{TRUE}, additional tests are performed. Default is \code{FALSE}
-#' @return an updated fitted linear model where outliers are dropped out.
-#' 
-#' @examples
-#' \dontrun{
-#' # fit linear model
-#' fit <- lm(airquality$Ozone ~ airquality$Wind + airquality$Temp + airquality$Solar.R)
-#' fit.updated <- sjp.lm.ma(fit)
-#' 
-#' data(efc)
-#' fit <- lm(tot_sc_e ~ c12hour + e17age + e42dep, data=efc)
-#' fit.updated <- sjp.lm.ma(fit, completeDiagnostic = TRUE)}
-#' 
-#' @importFrom car outlierTest crPlots durbinWatsonTest leveragePlots ncvTest spreadLevelPlot
-#' @export
 sjp.lm.ma <- function(linreg, showOriginalModelOnly=TRUE, completeDiagnostic=FALSE) {
   # ------------------------
   # check if suggested package is available
@@ -717,90 +772,6 @@ sjp.lm.ma <- function(linreg, showOriginalModelOnly=TRUE, completeDiagnostic=FAL
 }
 
 
-#' @title Plot regression line of fitted lm
-#' @name sjp.lm1
-#' 
-#' @description Plot a regression line with confidence interval for a fitted model with only
-#'                one predictor (i.e. \code{lm(y~x)}).
-#'                This function may plot two lines: The resulting linear regression line
-#'                including confidence interval (in blue) by default, and a loess-smoothed line without
-#'                confidence interval (in red) if parameter \code{showLoess} is \code{TRUE}.
-#'                The better the linear relationship of predictor and response is, the more both lines should overlap
-#'                (i.e. the red loess-smoothed line is almost linear). \cr \cr
-#'                Furthermore, a scatter plot of response and predictor values
-#'                is plotted.
-#'                
-#' @seealso \itemize{
-#'              \item \href{http://www.strengejacke.de/sjPlot/sjp.lm}{sjPlot manual: sjp.lm}
-#'              \item \code{\link{sjp.lm}}
-#'              \item \code{\link{sjp.reglin}}
-#'              \item \code{\link{sjp.scatter}}
-#'             }
-#'          
-#' @param fit The model of the linear regression (lm-Object).
-#' @param title Diagram's title as string.
-#'          Example: \code{title=c("my title")}
-#' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
-#'          one line and when a line break is inserted into the title
-#' @param axisLabel.x Labels of the predictor (independent variable) that is used for labelling the
-#'          axis. Passed as string.
-#'          Example: \code{axisLabel.x=c("My Predictor Var")}.
-#'          Note: If you use the \code{\link{sji.SPSS}} function and the \code{\link{sji.getVariableLabels}} function, you receive a
-#'          character vector with variable label strings. You can use it like so:
-#'          \code{axisLabel.x=sji.getVariableLabels(efc)['quol_5']}
-#' @param axisLabel.y Labels of the response (dependent variable) that is used for labelling the
-#'          axis. Passed as string.
-#'          Example: \code{axisLabel.y=c("My Depdendent Var")}.
-#'          Note: If you use the \code{\link{sji.SPSS}} function and the \code{\link{sji.getVariableLabels}} function, you receive a
-#'          character vector with variable label strings. You can use it like so:
-#'          \code{axisLabel.y=sji.getVariableLabels(efc)['neg_c_7']}
-#' @param breakLabelsAt Wordwrap for axis labels. Determines how many chars of the category labels are displayed in 
-#'          one line and when a line break is inserted
-#' @param lineColor The color of the regression line. Default is \code{"blue"}.
-#' @param showCI If \code{TRUE} (default), a confidence region for the regression line
-#'          will be plotted. Use \code{ciLevel} to specifiy the confidence level.
-#' @param ciLevel The confidence level of the confidence region. Only applies when
-#'          \code{showCI} is \code{TRUE}. Default is 0.95.
-#' @param pointAlpha The alpha values of the scatter plot's point-geoms.
-#'          Default is 0.2.
-#' @param pointColor The color of the scatter plot's point-geoms. Only applies when \code{showScatterPlot}
-#'          is \code{TRUE}. Default is \code{"black"}.
-#' @param showScatterPlot If \code{TRUE} (default), a scatter plot of response and predictor values
-#'          for each predictor of the fitted model \code{fit} is plotted.
-#' @param showLoess If \code{TRUE}, an additional loess-smoothed line is plotted.
-#' @param loessLineColor The color of the loess-smoothed line. Default is \code{"red"}. Only applies, if
-#'          \code{showLoess} is \code{TRUE}.
-#' @param showLoessCI If \code{TRUE}, a confidence region for the loess-smoothed line
-#'          will be plotted. Default is \code{FALSE}. Use \code{loessCiLevel} to specifiy the confidence level.
-#'          Only applies, if \code{showLoess} is \code{TRUE}.
-#' @param loessCiLevel The confidence level of the loess-line's confidence region.
-#'          Only applies, if \code{showLoessCI} is \code{TRUE}. Default is 0.95.
-#' @param showModelSummary If \code{TRUE} (default), a summary of the regression model with 
-#'          Intercept, R-square, F-Test and AIC-value is printed to the lower right corner
-#'          of the diagram.
-#' @param useResiduals If \code{TRUE}, the residuals (instead of response) are plotted 
-#'          against the predictor. May be used for model diagnostics
-#'          (see \url{https://www.otexts.org/fpp/5/4}).
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
-#' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
-#'           was used for setting up the ggplot-object (\code{df}).
-#' 
-#' @examples
-#' # load sample data
-#' data(efc)
-#' # fit model
-#' fit <- lm(neg_c_7 ~ quol_5, data=efc, na.action=na.omit)
-#' # plot regression line
-#' sjp.lm1(fit)
-#' # plot regression line with label strings
-#' sjp.lm1(fit,
-#'         axisLabel.x = sji.getVariableLabels(efc$quol_5),
-#'         axisLabel.y = sji.getVariableLabels(efc$neg_c_7),
-#'         showLoess = TRUE)
-#' 
-#' @import ggplot2
-#' @export
 sjp.lm1 <- function(fit,
                    title=NULL,
                    breakTitleAt=50, 
